@@ -97,13 +97,19 @@ class CategoryFilter(filters.FilterSet):
     def by_store(self, queryset, name, value):
         return (
             queryset.prefetch_related(
+                Prefetch(
+                    "subcategories",
+                    queryset=Category.objects.exclude(
+                        products__isnull=True,
+                    ),
+                ),
                 Prefetch(
                     "subcategories__products",
                     queryset=Product.objects.filter(
                         product_variants__inventories__store=value,
                         is_active=True,
                     ),
-                )
+                ),
             )
             .filter(subcategories__products__product_variants__inventories__store=value)
             .distinct()
