@@ -359,10 +359,9 @@ class ProductVariantSerializer(serializers.ModelSerializer):
         return True if obj.inventories.filter(is_primary=True).exists() else False
 
     def get_active_inventories(self, obj):
-        if obj.inventories.filter(is_active=True).exists():
-            return obj.inventories.filter(is_active=True).values(
-                "price", "store", "discount_percent"
-            )
+        qs = obj.inventories.filter(is_active=True)
+        if qs.exists():
+            return qs.values("price", "store", "discount_percent")
 
 
 class CartItemSerializer(InventoryValidationMixin, serializers.ModelSerializer):
