@@ -684,7 +684,7 @@ class ShippingMethodViewSet(
         """
         if we get store_pk=0 we fetch all the shipping methods
         """
-        if self.kwargs["store_pk"] == 0:
+        if int(self.kwargs["store_pk"]) == 0:
             return ShippingMethod.objects.filter(is_active=True)
         try:
             store = Store.objects.get(pk=self.kwargs["store_pk"])
