@@ -2,6 +2,7 @@ from datetime import timedelta
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
+from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
@@ -19,15 +20,20 @@ class Inventory(DjangoModelCleanMixin, models.Model):
         "stores.ProductVariant", on_delete=models.CASCADE, related_name="inventories"
     )
     store = models.ForeignKey(
-        "stores.Store", on_delete=models.CASCADE, related_name="inventories"
+        "stores.Store",
+        on_delete=models.CASCADE,
+        related_name="inventories",
+        null=True,
+        blank=True,
     )
     quantity = models.PositiveIntegerField(default=0)
     is_active = models.BooleanField(default=True)
-    price = models.DecimalField(max_digits=10, decimal_places=2, default=0)
-    discount_percent = models.DecimalField(max_digits=10, decimal_places=2, default=0)
+    price = models.DecimalField(max_digits=10, decimal_places=3, default=0)
+    discount_percent = models.DecimalField(max_digits=10, decimal_places=3, default=0)
     is_deliverable = models.BooleanField(default=False)
+    is_uncountable = models.BooleanField(default=True)
     # Add is_primary for variant
-    is_primary = models.BooleanField(default=False)
+    is_primary = models.BooleanField(default=True)
     preparation_time = models.DurationField(
         default=timedelta(minutes=0),
         help_text=_("Preparation time in minutes"),
@@ -43,7 +49,7 @@ class Inventory(DjangoModelCleanMixin, models.Model):
         verbose_name = _("Inventory")
 
     def __str__(self):
-        return f"Inventory - {self.variant.product.name} - {self.store.name}"
+        return f"Inventory - {self.variant.product.name} - {getattr(self.store,'name', None)}"
 
     @property
     def discounted_price(self) -> Decimal:
@@ -51,6 +57,19 @@ class Inventory(DjangoModelCleanMixin, models.Model):
             return self.price - (self.price * (self.discount_percent / 100))
         return self.price
 
+    def clean(self):
+        super(Inventory, self).clean()
+        if self.variant.product.type == "PHYSICAL" and not self.store:
+            raise ValidationError(_("The store attribute can not be null"))
+
+    def decrease(self, decreased_quantity):
+        if self.is_uncountable:
+            return
+        self.quantity = self.quantity - decreased_quantity
+        if self.quantity < 0:
+            raise ValidationError(_("This product is out of stock"))
+        self.save()
+
 
 class InventoryOperations(DjangoModelCleanMixin, models.Model):
     """model to log inventory operations"""
