@@ -16,6 +16,11 @@ class Order(DjangoModelCleanMixin, models.Model):
     - it contains order-items
     """
 
+    class OrderType(models.TextChoices):
+        PHYSICAL = "PHYSICAL", _("physical")
+        GIFT = "GIFT", _("gift")
+        WALLET = "WALLET", _("wallet")
+
     class OrderStatus(models.TextChoices):
         ACCEPTED = "ACCEPTED", _("accepted")
         CANCELLED = "CANCELLED", _("cancelled")
@@ -34,7 +39,11 @@ class Order(DjangoModelCleanMixin, models.Model):
         get_user_model(), related_name="orders", on_delete=models.CASCADE
     )
     store = models.ForeignKey(
-        "stores.Store", related_name="orders", on_delete=models.CASCADE
+        "stores.Store",
+        related_name="orders",
+        on_delete=models.CASCADE,
+        null=True,
+        blank=True,
     )
     shipping_method = models.ForeignKey(
         "stores.ShippingMethod",
@@ -54,11 +63,15 @@ class Order(DjangoModelCleanMixin, models.Model):
         "stores.address",
         on_delete=models.PROTECT,
         related_name="orders",
+        null=True,
+        blank=True,
     )
     immutable_shipping_address = models.ForeignKey(
         "stores.ImmutableAddress",
         on_delete=models.PROTECT,
         related_name="orders",
+        null=True,
+        blank=True,
     )
     status = models.CharField(
         max_length=32,
@@ -70,6 +83,7 @@ class Order(DjangoModelCleanMixin, models.Model):
         null=True, blank=True, help_text=_("Pickup time")
     )
     # Pick up can be now or a later hour during the day. If pickup_time is not set,
+    extra_infos = models.JSONField(null=True, blank=True)
 
     # TODO: add pick_up_time maybe ?
     # audit fields
@@ -103,16 +117,27 @@ class Order(DjangoModelCleanMixin, models.Model):
 
     @property
     def total_amount(self):
-
-        return Decimal(
+        amount = Decimal(
             sum(map(lambda item: Decimal(item.total_amount) or 0, self.items.all()))
         )
+        if self.shipping_method:
+            amount += self.shipping_method.shipping_fee
+        return amount
 
     @property
     def preparation_time(self):
         # sum of durations of all items in minutes
         return sum(map(lambda item: item.preparation_time, self.items.all()))
 
+    @property
+    def type_of_order(self):
+        if not self.extra_infos:
+            return self.OrderType.PHYSICAL.value
+        is_wallet = self.extra_infos.get("is_wallet_fill_up")
+        if is_wallet:
+            return self.OrderType.WALLET.value
+        return self.OrderType.GIFT.value
+
     def save(self, **kwargs):
         if not self.pk and self.shipping_address:
             self.immutable_shipping_address = self.shipping_address.to_immutable()
@@ -151,6 +176,7 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
         ],
         help_text=_("quantity of the variant"),
     )
+    extra_infos = models.JSONField(null=True, blank=True)
 
     def __str__(self):
         return f"OrderItem - {self.quantity} {self.product_variant.name}"
@@ -159,13 +185,20 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
         verbose_name = _("Order Item")
         verbose_name_plural = _("Order Items")
 
+    @property
+    def attribute_choices_total_amount(self):
+        total_price = Decimal(0)
+        for attribute_choice in self.attribute_choices.all():
+            total_price += attribute_choice.price
+        return total_price
+
     @property
     def total_amount(self):
         try:
             return (
                 self.product_variant.inventories.get(store=self.order.store).price
-                * self.quantity
-            )
+                + self.attribute_choices_total_amount
+            ) * self.quantity
         except ObjectDoesNotExist:
             return 0
 
@@ -179,7 +212,7 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
         ) / 60
 
     @property
-    def inventory(self) -> Decimal:
+    def inventory(self):
         try:
             return self.product_variant.inventories.get(store=self.order.store)
         except ObjectDoesNotExist:
