@@ -19,6 +19,11 @@ class ShippingMethod(models.Model):
     Decides how orders should be delivered to the customer.
     """
 
+    class ShippingType(models.TextChoices):
+        DRIVE_THROUGH = "DRIVE_THROUGH"
+        TAKEAWAY = "TAKEAWAY"
+        DELIVERY = "DELIVERY"
+
     class ShippingFeeOptions(models.IntegerChoices):
         """
         Decides how the shipping fees should be calculated.
@@ -28,6 +33,9 @@ class ShippingMethod(models.Model):
         PER_DISTANCE = 2, _("per distance")
         PER_WEIGHT = 3, _("per weight")
 
+    type = models.CharField(
+        max_length=30, choices=ShippingType.choices, default=ShippingType.DELIVERY
+    )
     shipping_fee_option = models.IntegerField(
         choices=ShippingFeeOptions.choices, default=1
     )
@@ -59,9 +67,10 @@ class PaymentMethod(models.Model):
     products are paid.
     """
 
-    payment_provider = models.PositiveSmallIntegerField(
+    payment_provider = models.CharField(
+        max_length=12,
         choices=settings.PAYMENT_PROVIDER_CHOICES,
-        default=1,
+        default="cod",
     )
     is_active = models.BooleanField(default=True)
     name = models.CharField(max_length=200, help_text=_("Name"))
